@@ -1,27 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt Creator.
-**
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
 
 #include "../coreplugin.h"
 
@@ -30,6 +8,7 @@
 
 #include <coreplugin/testdatadir.h>
 #include <utils/algorithm.h>
+#include <utils/filepath.h>
 #include <utils/fileutils.h>
 
 #include <QDir>
@@ -40,12 +19,12 @@ using namespace Core::Tests;
 
 namespace {
 
-QTC_DECLARE_MYTESTDATADIR("../../../../tests/locators/")
+QTC_DECLARE_MYTESTDATADIR("../../../tests/locators/")
 
 class MyBaseFileFilter : public Core::BaseFileFilter
 {
 public:
-    MyBaseFileFilter(const QStringList &theFiles)
+    MyBaseFileFilter(const Utils::FilePaths &theFiles)
     {
         setFileIterator(new BaseFileFilter::ListIterator(theFiles));
     }
@@ -74,10 +53,10 @@ void Core::Internal::CorePlugin::test_basefilefilter()
     QFETCH(QStringList, testFiles);
     QFETCH(QList<ReferenceData>, referenceDataList);
 
-    MyBaseFileFilter filter(testFiles);
+    MyBaseFileFilter filter(Utils::FileUtils::toFilePathList(testFiles));
     BasicLocatorFilterTest test(&filter);
 
-    for (const ReferenceData &reference : qAsConst(referenceDataList)) {
+    for (const ReferenceData &reference : std::as_const(referenceDataList)) {
         const QList<LocatorFilterEntry> filterEntries = test.matchesFor(reference.searchText);
         const ResultDataList results = ResultData::fromFilterEntryList(filterEntries);
 //        QTextStream(stdout) << "----" << endl;
@@ -89,7 +68,7 @@ void Core::Internal::CorePlugin::test_basefilefilter()
 void Core::Internal::CorePlugin::test_basefilefilter_data()
 {
     auto shortNativePath = [](const QString &file) {
-        return Utils::FileUtils::shortNativePath(Utils::FileName::fromString(file));
+        return Utils::FilePath::fromString(file).shortNativePath();
     };
 
     QTest::addColumn<QStringList>("testFiles");
