@@ -1,59 +1,40 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 BlackBerry Limited. All rights reserved
-** Contact: KDAB (info@kdab.com)
-**
-** This file is part of Qt Creator.
-**
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-****************************************************************************/
+// Copyright (C) 2016 BlackBerry Limited. All rights reserved
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
 
 #include "qnxutils.h"
-#include "qnxqtversion.h"
 
 #include <utils/algorithm.h>
 #include <utils/fileutils.h>
 #include <utils/hostosinfo.h>
-#include <utils/synchronousprocess.h>
+#include <utils/qtcprocess.h>
 #include <utils/temporaryfile.h>
 
 #include <QDebug>
 #include <QDir>
 #include <QDirIterator>
 #include <QDomDocument>
-#include <QProcess>
 #include <QStandardPaths>
 #include <QApplication>
 
 using namespace ProjectExplorer;
-using namespace Qnx;
-using namespace Qnx::Internal;
+using namespace Utils;
+
+namespace Qnx::Internal {
 
-namespace {
 const char *EVAL_ENV_VARS[] = {
-    "QNX_TARGET", "QNX_HOST", "QNX_CONFIGURATION", "MAKEFLAGS", "LD_LIBRARY_PATH",
-    "PATH", "QDE", "CPUVARDIR", "PYTHONPATH"
+    "QNX_TARGET", "QNX_HOST", "QNX_CONFIGURATION", "QNX_CONFIGURATION_EXCLUSIVE",
+    "MAKEFLAGS", "LD_LIBRARY_PATH", "PATH", "QDE", "CPUVARDIR", "PYTHONPATH"
 };
-}
 
-QString QnxUtils::addQuotes(const QString &string)
+QString QnxUtils::cpuDirFromAbi(const Abi &abi)
 {
-    return QLatin1Char('"') + string + QLatin1Char('"');
+    if (abi.os() != Abi::OS::QnxOS)
+        return QString();
+    if (abi.architecture() == Abi::Architecture::ArmArchitecture)
+        return QString::fromLatin1(abi.wordWidth() == 32 ? "armle-v7" : "aarch64le");
+    if (abi.architecture() == Abi::Architecture::X86Architecture)
+        return QString::fromLatin1(abi.wordWidth() == 32 ? "x86" : "x86_64");
+    return QString();
 }
 
 QString QnxUtils::cpuDirShortDescription(const QString &cpuDir)
@@ -73,18 +54,17 @@ QString QnxUtils::cpuDirShortDescription(const QString &cpuDir)
     return cpuDir;
 }
 
-QList<Utils::EnvironmentItem> QnxUtils::qnxEnvironmentFromEnvFile(const QString &fileName)
+EnvironmentItems QnxUtils::qnxEnvironmentFromEnvFile(const FilePath &filePath)
 {
-    QList <Utils::EnvironmentItem> items;
+    EnvironmentItems items;
 
-    if (!QFileInfo::exists(fileName))
+    if (!filePath.exists())
         return items;
 
-    const bool isWindows = Utils::HostOsInfo::isWindowsHost();
+    const bool isWindows = HostOsInfo::isWindowsHost();
 
     // locking creating sdp-env file wrapper script
-    Utils::TemporaryFile tmpFile(QString::fromLatin1("sdp-env-eval-XXXXXX")
-                                 + QString::fromLatin1(isWindows ? ".bat" : ".sh"));
+    TemporaryFile tmpFile("sdp-env-eval-XXXXXX" + QString::fromLatin1(isWindows ? ".bat" : ".sh"));
     if (!tmpFile.open())
         return items;
     tmpFile.setTextModeEnabled(true);
@@ -92,71 +72,66 @@ QList<Utils::EnvironmentItem> QnxUtils::qnxEnvironmentFromEnvFile(const QString
     // writing content to wrapper script
     QTextStream fileContent(&tmpFile);
     if (isWindows)
-        fileContent << QLatin1String("@echo off\n")
-                    << QLatin1String("call ") << fileName << QLatin1Char('\n');
+        fileContent << "@echo off\n"
+                    << "call " << filePath.path() << '\n';
     else
-        fileContent << QLatin1String("#!/bin/bash\n")
-                    << QLatin1String(". ") << fileName << QLatin1Char('\n');
+        fileContent << "#!/bin/bash\n"
+                    << ". " << filePath.path() << '\n';
     QString linePattern = QString::fromLatin1(isWindows ? "echo %1=%%1%" : "echo %1=$%1");
     for (int i = 0, len = sizeof(EVAL_ENV_VARS) / sizeof(const char *); i < len; ++i)
         fileContent << linePattern.arg(QLatin1String(EVAL_ENV_VARS[i])) << QLatin1Char('\n');
     tmpFile.close();
 
     // running wrapper script
-    QProcess process;
+    QtcProcess process;
     if (isWindows)
-        process.start(QLatin1String("cmd.exe"),
-                QStringList() << QLatin1String("/C") << tmpFile.fileName());
+        process.setCommand({"cmd.exe", {"/C", tmpFile.fileName()}});
     else
-        process.start(QLatin1String("/bin/bash"),
-                QStringList() << tmpFile.fileName());
+        process.setCommand({"/bin/bash", {tmpFile.fileName()}});
+    process.start();
 
     // waiting for finish
     QApplication::setOverrideCursor(Qt::BusyCursor);
-    bool waitResult = process.waitForFinished(10000) || process.state() == QProcess::NotRunning;
+    bool waitResult = process.waitForFinished(10000);
     QApplication::restoreOverrideCursor();
-    if (!waitResult) {
-        Utils::SynchronousProcess::stopProcess(process);
+    if (!waitResult)
         return items;
-    }
 
-    if (process.exitStatus() != QProcess::NormalExit || process.exitCode() != 0)
+    if (process.result() != ProcessResult::FinishedWithSuccess)
         return items;
 
     // parsing process output
-    QTextStream str(&process);
-    while (!str.atEnd()) {
-        QString line = str.readLine();
-        int equalIndex = line.indexOf(QLatin1Char('='));
+    const QString output = process.cleanedStdOut();
+    for (const QString &line : output.split('\n')) {
+        int equalIndex = line.indexOf('=');
         if (equalIndex < 0)
             continue;
         QString var = line.left(equalIndex);
         QString value = line.mid(equalIndex + 1);
-        items.append(Utils::EnvironmentItem(var, value));
+        items.append(EnvironmentItem(var, value));
     }
 
     return items;
 }
 
-QString QnxUtils::envFilePath(const QString &sdpPath)
+FilePath QnxUtils::envFilePath(const FilePath &sdpPath)
 {
-    QDir sdp(sdpPath);
-    QStringList entries;
-    if (Utils::HostOsInfo::isWindowsHost())
-        entries = sdp.entryList(QStringList(QLatin1String("*-env.bat")));
+    FilePaths entries;
+    if (sdpPath.osType() == OsTypeWindows)
+        entries = sdpPath.dirEntries({{"*-env.bat"}});
     else
-        entries = sdp.entryList(QStringList(QLatin1String("*-env.sh")));
+        entries = sdpPath.dirEntries({{"*-env.sh"}});
 
     if (!entries.isEmpty())
-        return sdp.absoluteFilePath(entries.first());
+        return entries.first();
 
-    return QString();
+    return {};
 }
 
 QString QnxUtils::defaultTargetVersion(const QString &sdpPath)
 {
     foreach (const ConfigInstallInformation &sdpInfo, installedConfigs()) {
-        if (!sdpInfo.path.compare(sdpPath, Utils::HostOsInfo::fileNameCaseSensitivity()))
+        if (!sdpInfo.path.compare(sdpPath, HostOsInfo::fileNameCaseSensitivity()))
             return sdpInfo.version;
     }
 
@@ -206,14 +181,13 @@ QList<ConfigInstallInformation> QnxUtils::installedConfigs(const QString &config
     return sdpList;
 }
 
-QList<Utils::EnvironmentItem> QnxUtils::qnxEnvironment(const QString &sdpPath)
+EnvironmentItems QnxUtils::qnxEnvironment(const FilePath &sdpPath)
 {
     return qnxEnvironmentFromEnvFile(envFilePath(sdpPath));
 }
 
-QList<QnxTarget> QnxUtils::findTargets(const Utils::FilePath &basePath)
+QList<QnxTarget> QnxUtils::findTargets(const FilePath &basePath)
 {
-    using namespace Utils;
     QList<QnxTarget> result;
 
     QDirIterator iterator(basePath.toString());
@@ -231,7 +205,7 @@ QList<QnxTarget> QnxUtils::findTargets(const Utils::FilePath &basePath)
                 qWarning() << libc << "has more than one ABI ... processing all";
 
             FilePath path = FilePath::fromString(iterator.filePath());
-            for (Abi abi : abis)
+            for (const Abi &abi : abis)
                 result.append(QnxTarget(path, QnxUtils::convertAbi(abi)));
         }
     }
@@ -255,3 +229,5 @@ Abis QnxUtils::convertAbis(const Abis &abis)
 {
     return Utils::transform(abis, &QnxUtils::convertAbi);
 }
+
+} // Qnx::Internal
